#
# This file is part of ElasticSearchX-Model
#
# This software is Copyright (c) 2012 by Moritz Onken.
#
# This is free software, licensed under:
#
#   The (three-clause) BSD License
#
package ElasticSearchX::Model::Document::Trait::Field::Version;
{
  $ElasticSearchX::Model::Document::Trait::Field::Version::VERSION = '0.1.3';
}
use Moose::Role;
use ElasticSearchX::Model::Document::Types qw(:all);

package ElasticSearchX::Model::Document::Trait::Class::Version;
{
  $ElasticSearchX::Model::Document::Trait::Class::Version::VERSION = '0.1.3';
}
use Moose::Role;


1;
__END__
=pod

=head1 NAME

ElasticSearchX::Model::Document::Trait::Field::Version

=head1 VERSION

version 0.1.3

=head1 AUTHOR

Moritz Onken

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Moritz Onken.

This is free software, licensed under:

  The (three-clause) BSD License

=cut

